@@ -10,41 +10,60 @@
 #include "lokalize_debug.h"
 
 #include "gettextheader.h"
+#include "prefs_lokalize.h"
 #include "project.h"
 #include "version.h"
-#include "prefs_lokalize.h"
 
-#include <QString>
-#include <QMap>
-#include <QDomDocument>
 #include <QElapsedTimer>
-#include <QPair>
 #include <QList>
+#include <QPair>
+#include <QString>
 #include <QXmlStreamReader>
 
 #include <klocalizedstring.h>
 
-static const QString names[] = {QStringLiteral("source"), QStringLiteral("translation"), QStringLiteral("oldsource"), QStringLiteral("translatorcomment"), QStringLiteral("comment"), QStringLiteral("name"), QStringLiteral("numerus")};
-enum TagNames                {SourceTag, TargetTag, OldSourceTag, NoteTag, DevNoteTag, NameTag, PluralTag};
+static const QString names[] = {QStringLiteral("source"),
+                                QStringLiteral("translation"),
+                                QStringLiteral("oldsource"),
+                                QStringLiteral("translatorcomment"),
+                                QStringLiteral("comment"),
+                                QStringLiteral("name"),
+                                QStringLiteral("numerus")};
+enum TagNames {
+    SourceTag,
+    TargetTag,
+    OldSourceTag,
+    NoteTag,
+    DevNoteTag,
+    NameTag,
+    PluralTag,
+};
 
 static const QString attrnames[] = {QStringLiteral("location"), QStringLiteral("type"), QStringLiteral("obsolete")};
-enum AttrNames                   {LocationAttr, TypeAttr, ObsoleteAttr};
+enum AttrNames {
+    LocationAttr,
+    TypeAttr,
+    ObsoleteAttr,
+};
 
 static const QString attrvalues[] = {QStringLiteral("obsolete"), QStringLiteral("vanished")};
-enum AttValues                    {ObsoleteVal, VanishedVal};
+enum AttValues {
+    ObsoleteVal,
+    VanishedVal,
+};
 
-static QString protect(const QString & str)
+static QString protect(const QString &str)
 {
     QString p = str;
     p.replace(QLatin1Char('&'), QLatin1String("&amp;"));
     p.replace(QLatin1Char('\"'), QLatin1String("&quot;"));
-    p.replace(QLatin1Char('>'),  QLatin1String("&gt;"));
-    p.replace(QLatin1Char('<'),  QLatin1String("&lt;"));
+    p.replace(QLatin1Char('>'), QLatin1String("&gt;"));
+    p.replace(QLatin1Char('<'), QLatin1String("&lt;"));
     p.replace(QLatin1Char('\''), QLatin1String("&apos;"));
     return p;
 }
 
-static QString unprotect(const QString & str)
+static QString unprotect(const QString &str)
 {
     QString p = str;
     p.replace(QLatin1String("&amp;"), QLatin1String("&"));
@@ -57,36 +76,36 @@ static QString unprotect(const QString & str)
 
 int TsStorage::capabilities() const
 {
-    return 0;//MultipleNotes;
+    return 0; // MultipleNotes;
 }
 
-//BEGIN OPEN/SAVE
+// BEGIN OPEN/SAVE
 
-int TsStorage::load(QIODevice* device)
+int TsStorage::load(QIODevice *device)
 {
-    QElapsedTimer chrono; chrono.start();
+    QElapsedTimer chrono;
+    chrono.start();
 
     QXmlStreamReader reader(device);
     reader.setNamespaceProcessing(false);
 
     QString errorMsg;
-    int errorLine{};//+errorColumn;
-    bool success = m_doc.setContent(&reader, false, &errorMsg, &errorLine/*,errorColumn*/);
+    int errorLine{}; //+errorColumn;
+    bool success = m_doc.setContent(&reader, false, &errorMsg, &errorLine /*,errorColumn*/);
 
     if (!success) {
         qCWarning(LOKALIZE_LOG) << "parse error" << errorMsg << errorLine;
         return errorLine + 1;
     }
 
-
     QDomElement file = m_doc.elementsByTagName(QStringLiteral("TS")).at(0).toElement();
     m_sourceLangCode = file.attribute(QStringLiteral("sourcelanguage"));
     m_targetLangCode = file.attribute(QStringLiteral("language"));
     m_numberOfPluralForms = numberOfPluralFormsForLangCode(m_targetLangCode);
 
-    //Create entry mapping.
-    //Along the way: for langs with more than 2 forms
-    //we create any form-entries additionally needed
+    // Create entry mapping.
+    // Along the way: for langs with more than 2 forms
+    // we create any form-entries additionally needed
 
     entries = m_doc.elementsByTagName(QStringLiteral("message"));
     if (!Settings::self()->convertXMLChars()) {
@@ -124,7 +143,7 @@ int TsStorage::load(QIODevice* device)
     return 0;
 }
 
-bool TsStorage::save(QIODevice* device, bool belongsToProject)
+bool TsStorage::save(QIODevice *device, bool belongsToProject)
 {
     Q_UNUSED(belongsToProject)
     QTextStream stream(device);
@@ -188,22 +207,22 @@ bool TsStorage::save(QIODevice* device, bool belongsToProject)
             }
         }
         stream << tempString.replace(QStringLiteral("<source><![CDATA["), QStringLiteral("<source>"))
-               .replace(QStringLiteral("<translation><![CDATA["), QStringLiteral("<translation>"))
-               .replace(QStringLiteral("<numerusform><![CDATA["), QStringLiteral("<numerusform>"))
-               .replace(QStringLiteral("<translation type=\"vanished\"><![CDATA["), QStringLiteral("<translation type=\"vanished\">"))
-               .replace(QStringLiteral("<translation type=\"unfinished\"><![CDATA["), QStringLiteral("<translation type=\"unfinished\">"))
-               .replace(QStringLiteral("<translation type=\"obsolete\"><![CDATA["), QStringLiteral("<translation type=\"obsolete\">"))
-               .replace(QStringLiteral("<translatorcomment><![CDATA["), QStringLiteral("<translatorcomment>"))
-               .replace(QStringLiteral("]]></source>"), QStringLiteral("</source>"))
-               .replace(QStringLiteral("]]></translation>"), QStringLiteral("</translation>"))
-               .replace(QStringLiteral("]]></numerusform>"), QStringLiteral("</numerusform>"))
-               .replace(QStringLiteral("]]></translatorcomment>"), QStringLiteral("</translatorcomment>"));
+                      .replace(QStringLiteral("<translation><![CDATA["), QStringLiteral("<translation>"))
+                      .replace(QStringLiteral("<numerusform><![CDATA["), QStringLiteral("<numerusform>"))
+                      .replace(QStringLiteral("<translation type=\"vanished\"><![CDATA["), QStringLiteral("<translation type=\"vanished\">"))
+                      .replace(QStringLiteral("<translation type=\"unfinished\"><![CDATA["), QStringLiteral("<translation type=\"unfinished\">"))
+                      .replace(QStringLiteral("<translation type=\"obsolete\"><![CDATA["), QStringLiteral("<translation type=\"obsolete\">"))
+                      .replace(QStringLiteral("<translatorcomment><![CDATA["), QStringLiteral("<translatorcomment>"))
+                      .replace(QStringLiteral("]]></source>"), QStringLiteral("</source>"))
+                      .replace(QStringLiteral("]]></translation>"), QStringLiteral("</translation>"))
+                      .replace(QStringLiteral("]]></numerusform>"), QStringLiteral("</numerusform>"))
+                      .replace(QStringLiteral("]]></translatorcomment>"), QStringLiteral("</translatorcomment>"));
     }
     return true;
 }
-//END OPEN/SAVE
+// END OPEN/SAVE
 
-//BEGIN STORAGE TRANSLATION
+// BEGIN STORAGE TRANSLATION
 
 int TsStorage::size() const
 {
@@ -214,35 +233,43 @@ int TsStorage::size() const
  * helper structure used during XLIFF XML walk-through
  */
 struct TsContentEditingData {
-    enum ActionType {Get, DeleteText, InsertText, CheckLength};
+    enum ActionType {
+        Get,
+        DeleteText,
+        InsertText,
+        CheckLength,
+    };
 
     QString stringToInsert;
     int pos{-1};
     int lengthOfStringToRemove{-1};
     ActionType actionType;
 
-    ///Get
+    /// Get
     explicit TsContentEditingData(ActionType type = Get)
         : actionType(type)
-    {}
+    {
+    }
 
-    ///DeleteText
+    /// DeleteText
     TsContentEditingData(int p, int l)
         : pos(p)
         , lengthOfStringToRemove(l)
         , actionType(DeleteText)
-    {}
+    {
+    }
 
-    ///InsertText
-    TsContentEditingData(int p, const QString& s)
+    /// InsertText
+    TsContentEditingData(int p, const QString &s)
         : stringToInsert(s)
         , pos(p)
         , lengthOfStringToRemove(-1)
         , actionType(InsertText)
-    {}
+    {
+    }
 };
 
-static QString doContent(QDomElement elem, int startingPos, TsContentEditingData* data);
+static QString doContent(QDomElement elem, int startingPos, TsContentEditingData *data);
 
 /**
  * walks through TS XML and performs actions depending on TsContentEditingData:
@@ -250,19 +277,18 @@ static QString doContent(QDomElement elem, int startingPos, TsContentEditingData
  * - deletes content, or
  * - inserts content
  */
-static QString content(QDomElement elem, TsContentEditingData* data = nullptr)
+static QString content(QDomElement elem, TsContentEditingData *data = nullptr)
 {
     return doContent(elem, 0, data);
 }
 
-static QString doContent(QDomElement elem, int startingPos, TsContentEditingData* data)
+static QString doContent(QDomElement elem, int startingPos, TsContentEditingData *data)
 {
-    //actually startingPos is current pos
+    // actually startingPos is current pos
 
     QString result;
 
-    if (elem.isNull()
-        || (data && data->actionType == TsContentEditingData::CheckLength))
+    if (elem.isNull() || (data && data->actionType == TsContentEditingData::CheckLength))
         return QString();
 
     bool seenCDataAfterElement = false;
@@ -274,34 +300,33 @@ static QString doContent(QDomElement elem, int startingPos, TsContentEditingData
 
             QDomCharacterData c = Settings::self()->convertXMLChars() ? n.toCharacterData() : n.toCDATASection();
             QString cData = c.data();
-            if (data && data->pos != -1 &&
-                data->pos >= startingPos && data->pos <= startingPos + cData.size()) {
+            if (data && data->pos != -1 && data->pos >= startingPos && data->pos <= startingPos + cData.size()) {
                 // time to do some action! ;)
                 int localStartPos = data->pos - startingPos;
 
-                //BEGIN DELETE TEXT
+                // BEGIN DELETE TEXT
                 if (data->actionType == TsContentEditingData::DeleteText) { //(data->lengthOfStringToRemove!=-1)
                     if (localStartPos + data->lengthOfStringToRemove > cData.size()) {
-                        //text is fragmented into several QDomCData
+                        // text is fragmented into several QDomCData
                         int localDelLen = cData.size() - localStartPos;
                         c.deleteData(localStartPos, localDelLen);
-                        //setup data for future iterations
+                        // setup data for future iterations
                         data->lengthOfStringToRemove = data->lengthOfStringToRemove - localDelLen;
-                        //data->pos=startingPos;
-                        //qCWarning(LOKALIZE_LOG)<<"\tsetup:"<<data->pos<<data->lengthOfStringToRemove;
+                        // data->pos=startingPos;
+                        // qCWarning(LOKALIZE_LOG)<<"\tsetup:"<<data->pos<<data->lengthOfStringToRemove;
                     } else {
-                        //qCWarning(LOKALIZE_LOG)<<"simple delete"<<localStartPos<<data->lengthOfStringToRemove;
+                        // qCWarning(LOKALIZE_LOG)<<"simple delete"<<localStartPos<<data->lengthOfStringToRemove;
                         c.deleteData(localStartPos, data->lengthOfStringToRemove);
                         data->actionType = TsContentEditingData::CheckLength;
-                        return QStringLiteral("a");//so it exits 100%
+                        return QStringLiteral("a"); // so it exits 100%
                     }
                 }
-                //END DELETE TEXT
-                //INSERT
+                // END DELETE TEXT
+                // INSERT
                 else if (data->actionType == TsContentEditingData::InsertText) {
                     c.insertData(localStartPos, data->stringToInsert);
                     data->actionType = TsContentEditingData::CheckLength;
-                    return QStringLiteral("a");//so it exits 100%
+                    return QStringLiteral("a"); // so it exits 100%
                 }
                 cData = c.data();
             }
@@ -312,19 +337,15 @@ static QString doContent(QDomElement elem, int startingPos, TsContentEditingData
         n = n.nextSibling();
     }
     if (!seenCDataAfterElement) {
-        //add empty cDATA child so that user could add some text
-        elem.appendChild(Settings::self()->convertXMLChars() ?
-                         elem.ownerDocument().createTextNode(QString()) :
-                         elem.ownerDocument().createCDATASection(QString())
-                        );
+        // add empty cDATA child so that user could add some text
+        elem.appendChild(Settings::self()->convertXMLChars() ? elem.ownerDocument().createTextNode(QString())
+                                                             : elem.ownerDocument().createCDATASection(QString()));
     }
 
     return result;
 }
 
-
-
-//flat-model interface (ignores XLIFF grouping)
+// flat-model interface (ignores XLIFF grouping)
 
 CatalogString TsStorage::catalogString(QDomElement contentElement) const
 {
@@ -334,7 +355,7 @@ CatalogString TsStorage::catalogString(QDomElement contentElement) const
     return catalogString;
 }
 
-CatalogString TsStorage::catalogString(const DocPosition& pos) const
+CatalogString TsStorage::catalogString(const DocPosition &pos) const
 {
     return catalogString(pos.part == DocPosition::Target ? targetForPos(pos) : sourceForPos(pos.entry));
 }
@@ -348,16 +369,16 @@ CatalogString TsStorage::sourceWithTags(DocPosition pos) const
     return catalogString(sourceForPos(pos.entry));
 }
 
-QString TsStorage::source(const DocPosition& pos) const
+QString TsStorage::source(const DocPosition &pos) const
 {
     return content(sourceForPos(pos.entry));
 }
-QString TsStorage::target(const DocPosition& pos) const
+QString TsStorage::target(const DocPosition &pos) const
 {
     return content(targetForPos(pos));
 }
 
-QString TsStorage::sourceWithPlurals(const DocPosition& pos, bool truncateFirstLine) const
+QString TsStorage::sourceWithPlurals(const DocPosition &pos, bool truncateFirstLine) const
 {
     QString str = source(pos);
     if (truncateFirstLine) {
@@ -367,7 +388,7 @@ QString TsStorage::sourceWithPlurals(const DocPosition& pos, bool truncateFirstL
     }
     return str;
 }
-QString TsStorage::targetWithPlurals(const DocPosition& pos, bool truncateFirstLine) const
+QString TsStorage::targetWithPlurals(const DocPosition &pos, bool truncateFirstLine) const
 {
     QString str = target(pos);
     if (truncateFirstLine) {
@@ -378,45 +399,43 @@ QString TsStorage::targetWithPlurals(const DocPosition& pos, bool truncateFirstL
     return str;
 }
 
-
-void TsStorage::targetDelete(const DocPosition& pos, int count)
+void TsStorage::targetDelete(const DocPosition &pos, int count)
 {
     TsContentEditingData data(pos.offset, count);
     content(targetForPos(pos), &data);
 }
 
-void TsStorage::targetInsert(const DocPosition& pos, const QString& arg)
+void TsStorage::targetInsert(const DocPosition &pos, const QString &arg)
 {
     QDomElement targetEl = targetForPos(pos);
-    //BEGIN add <*target>
+    // BEGIN add <*target>
     if (targetEl.isNull()) {
         QDomNode unitEl = unitForPos(pos.entry);
         QDomNode refNode = unitEl.firstChildElement(names[SourceTag]);
         targetEl = unitEl.insertAfter(m_doc.createElement(names[TargetTag]), refNode).toElement();
 
         if (pos.entry < size()) {
-            targetEl.appendChild(Settings::self()->convertXMLChars() ?
-                                 m_doc.createTextNode(arg) :
-                                 m_doc.createCDATASection(arg));//i bet that pos.offset is 0 ;)
+            targetEl.appendChild(Settings::self()->convertXMLChars() ? m_doc.createTextNode(arg)
+                                                                     : m_doc.createCDATASection(arg)); // i bet that pos.offset is 0 ;)
             return;
         }
     }
-    //END add <*target>
-    if (arg.isEmpty()) return; //means we were called just to add <target> tag
+    // END add <*target>
+    if (arg.isEmpty())
+        return; // means we were called just to add <target> tag
 
     TsContentEditingData data(pos.offset, arg);
     content(targetEl, &data);
 }
 
-void TsStorage::setTarget(const DocPosition& pos, const QString& arg)
+void TsStorage::setTarget(const DocPosition &pos, const QString &arg)
 {
     Q_UNUSED(pos);
     Q_UNUSED(arg);
-//TODO
+    // TODO
 }
 
-
-QVector<AltTrans> TsStorage::altTrans(const DocPosition& pos) const
+QVector<AltTrans> TsStorage::altTrans(const DocPosition &pos) const
 {
     QVector<AltTrans> result;
 
@@ -427,8 +446,7 @@ QVector<AltTrans> TsStorage::altTrans(const DocPosition& pos) const
     return result;
 }
 
-
-QStringList TsStorage::sourceFiles(const DocPosition& pos) const
+QStringList TsStorage::sourceFiles(const DocPosition &pos) const
 {
     QStringList result;
 
@@ -441,12 +459,12 @@ QStringList TsStorage::sourceFiles(const DocPosition& pos) const
 
         elem = elem.nextSiblingElement(attrnames[LocationAttr]);
     }
-    //qSort(result);
+    // qSort(result);
 
     return result;
 }
 
-QVector<Note> TsStorage::notes(const DocPosition& pos) const
+QVector<Note> TsStorage::notes(const DocPosition &pos) const
 {
     QVector<Note> result;
 
@@ -465,7 +483,7 @@ QVector<Note> TsStorage::notes(const DocPosition& pos) const
     return result;
 }
 
-QVector<Note> TsStorage::developerNotes(const DocPosition& pos) const
+QVector<Note> TsStorage::developerNotes(const DocPosition &pos) const
 {
     QVector<Note> result;
 
@@ -480,7 +498,7 @@ QVector<Note> TsStorage::developerNotes(const DocPosition& pos) const
     return result;
 }
 
-Note TsStorage::setNote(DocPosition pos, const Note& note)
+Note TsStorage::setNote(DocPosition pos, const Note &note)
 {
     QDomElement unit = unitForPos(pos.entry);
     QDomElement elem;
@@ -488,12 +506,10 @@ Note TsStorage::setNote(DocPosition pos, const Note& note)
     if (pos.form == -1 && !note.content.isEmpty()) {
         QDomElement ref = unit.lastChildElement(names[NoteTag]);
         elem = unit.insertAfter(m_doc.createElement(names[NoteTag]), ref).toElement();
-        elem.appendChild(Settings::self()->convertXMLChars() ?
-                         m_doc.createTextNode(QString()) :
-                         m_doc.createCDATASection(QString()));
+        elem.appendChild(Settings::self()->convertXMLChars() ? m_doc.createTextNode(QString()) : m_doc.createCDATASection(QString()));
     } else {
         QDomNodeList list = unit.elementsByTagName(names[NoteTag]);
-        //if (pos.form==-1) pos.form=list.size()-1;
+        // if (pos.form==-1) pos.form=list.size()-1;
         if (pos.form < list.size()) {
             elem = unit.elementsByTagName(names[NoteTag]).at(pos.form).toElement();
             QDomNode n = elem.firstChild();
@@ -505,7 +521,8 @@ Note TsStorage::setNote(DocPosition pos, const Note& note)
         }
     }
 
-    if (elem.isNull()) return oldNote;
+    if (elem.isNull())
+        return oldNote;
 
     QDomNode n = elem.firstChild();
     if (!n.isNull()) {
@@ -525,14 +542,14 @@ Note TsStorage::setNote(DocPosition pos, const Note& note)
     return oldNote;
 }
 
-QStringList TsStorage::context(const DocPosition& pos) const
+QStringList TsStorage::context(const DocPosition &pos) const
 {
     QStringList result;
 
     QDomElement unit = unitForPos(pos.entry);
     QDomElement context = unit.parentNode().toElement();
-    //if (context.isNull())
-    //    return result;
+    // if (context.isNull())
+    //     return result;
 
     QDomElement name = context.firstChildElement(names[NameTag]);
     if (name.isNull())
@@ -542,13 +559,13 @@ QStringList TsStorage::context(const DocPosition& pos) const
     return result;
 }
 
-QStringList TsStorage::matchData(const DocPosition& pos) const
+QStringList TsStorage::matchData(const DocPosition &pos) const
 {
     Q_UNUSED(pos);
     return QStringList();
 }
 
-QString TsStorage::id(const DocPosition& pos) const
+QString TsStorage::id(const DocPosition &pos) const
 {
     QString result = source(pos);
     result.remove(QLatin1Char('\n'));
@@ -558,17 +575,17 @@ QString TsStorage::id(const DocPosition& pos) const
     return result;
 }
 
-bool TsStorage::isPlural(const DocPosition& pos) const
+bool TsStorage::isPlural(const DocPosition &pos) const
 {
     QDomElement unit = unitForPos(pos.entry);
 
     return unit.hasAttribute(names[PluralTag]);
 }
 
-void TsStorage::setApproved(const DocPosition& pos, bool approved)
+void TsStorage::setApproved(const DocPosition &pos, bool approved)
 {
-    targetInsert(pos, QString()); //adds <target> if needed
-    QDomElement targetElem = unitForPos(pos.entry).firstChildElement(names[TargetTag]); //asking directly to bypass plural state detection
+    targetInsert(pos, QString()); // adds <target> if needed
+    QDomElement targetElem = unitForPos(pos.entry).firstChildElement(names[TargetTag]); // asking directly to bypass plural state detection
     if (targetElem.attribute(attrnames[TypeAttr]) == attrvalues[ObsoleteVal])
         return;
     if (approved)
@@ -577,7 +594,7 @@ void TsStorage::setApproved(const DocPosition& pos, bool approved)
         targetElem.setAttribute(attrnames[TypeAttr], QStringLiteral("unfinished"));
 }
 
-bool TsStorage::isApproved(const DocPosition& pos) const
+bool TsStorage::isApproved(const DocPosition &pos) const
 {
     const QDomElement targetElem = unitForPos(pos.entry).firstChildElement(names[TargetTag]);
     return !targetElem.hasAttribute(attrnames[TypeAttr]) || targetElem.attribute(attrnames[TypeAttr]) == attrvalues[VanishedVal];
@@ -590,23 +607,23 @@ bool TsStorage::isObsolete(int entry) const
     return v == attrvalues[ObsoleteVal] || v == attrvalues[VanishedVal];
 }
 
-bool TsStorage::isEmpty(const DocPosition& pos) const
+bool TsStorage::isEmpty(const DocPosition &pos) const
 {
     TsContentEditingData data(TsContentEditingData::CheckLength);
     return content(targetForPos(pos), &data).isEmpty();
 }
 
-bool TsStorage::isEquivTrans(const DocPosition& pos) const
+bool TsStorage::isEquivTrans(const DocPosition &pos) const
 {
     Q_UNUSED(pos)
-    return true;//targetForPos(pos.entry).attribute("equiv-trans")!="no";
+    return true; // targetForPos(pos.entry).attribute("equiv-trans")!="no";
 }
 
-void TsStorage::setEquivTrans(const DocPosition& pos, bool equivTrans)
+void TsStorage::setEquivTrans(const DocPosition &pos, bool equivTrans)
 {
     Q_UNUSED(pos)
     Q_UNUSED(equivTrans)
-    //targetForPos(pos.entry).setAttribute("equiv-trans",noyes[equivTrans]);
+    // targetForPos(pos.entry).setAttribute("equiv-trans",noyes[equivTrans]);
 }
 
 QDomElement TsStorage::unitForPos(int pos) const
@@ -621,7 +638,8 @@ QDomElement TsStorage::targetForPos(DocPosition pos) const
     if (!unit.hasAttribute(names[PluralTag]))
         return translation;
 
-    if (pos.form == -1) pos.form = 0;
+    if (pos.form == -1)
+        pos.form = 0;
 
     const QDomNodeList forms = translation.elementsByTagName(QStringLiteral("numerusform"));
     while (pos.form >= forms.size())
@@ -634,7 +652,7 @@ QDomElement TsStorage::sourceForPos(int pos) const
     return unitForPos(pos).firstChildElement(names[SourceTag]);
 }
 
-void TsStorage::setTargetLangCode(const QString& langCode)
+void TsStorage::setTargetLangCode(const QString &langCode)
 {
     m_targetLangCode = langCode;
 
@@ -645,7 +663,4 @@ void TsStorage::setTargetLangCode(const QString& langCode)
     }
 }
 
-
-//END STORAGE TRANSLATION
-
-
+// END STORAGE TRANSLATION
