@@ -1,68 +1,57 @@
-/* **************************************************************************
+/*
   This file is part of Lokalize
 
   wordDiff algorithm adoption and further refinement:
   SPDX-FileCopyrightText: 2007 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
-  (based on Markus Stengel's GPL implementation of LCS-Delta algorithm as it is described in "Introduction to Algorithms", MIT Press, 2001, Second Edition, written by Thomas H. Cormen et. al. It uses dynamic programming to solve the Longest Common Subsequence (LCS) problem.)
+  SPDX-FileCopyrightText: 2024 Finley Watson <fin-w@tutanota.com>
+  (based on Markus Stengel's GPL implementation of LCS-Delta algorithm as it is described in "Introduction to Algorithms", MIT Press, 2001, Second Edition,
+  written by Thomas H. Cormen et. al. It uses dynamic programming to solve the Longest Common Subsequence (LCS) problem.)
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-
-************************************************************************** */
+*/
 
 #include "diff.h"
 
 #include "lokalize_debug.h"
 
-// #include "project.h"
-#include "prefs_lokalize.h"
-
-#include <QRegularExpression>
-#include <QVector>
-#include <QStringList>
-#include <QStringMatcher>
-#include <QStringBuilder>
-
 #include <list>
 
+#include <kcolorscheme.h>
+
+#include <QRegularExpression>
+#include <QStringBuilder>
+#include <QStringList>
+#include <QStringMatcher>
+#include <QTextFormat>
+#include <QVector>
 
 typedef enum {
-    NOTHING       = 0,
-    ARROW_UP      = 1,
-    ARROW_LEFT    = 2,
+    NOTHING = 0,
+    ARROW_UP = 1,
+    ARROW_LEFT = 2,
     ARROW_UP_LEFT = 3,
-    FINAL         = 4
+    FINAL = 4,
 } LCSMarker;
 
-static const QString addMarkerStart = QStringLiteral("<KBABELADD>");
-static const QString addMarkerEnd = QStringLiteral("</KBABELADD>");
-static const QString delMarkerStart = QStringLiteral("<KBABELDEL>");
-static const QString delMarkerEnd = QStringLiteral("</KBABELDEL>");
-
-QStringList calcLCS(const QStringList& s1Words,
-                    const QStringList& s2Words,
-                    const QStringList& s1Space,
-                    const QStringList& s2Space
-                   );
-
+QStringList calcLCS(const QStringList &s1Words, const QStringList &s2Words, const QStringList &s1Space, const QStringList &s2Space);
 
 /**
-     * The class is used for keeping "global" params of recursive function
-     *
-     * @short Class for keeping "global" params of recursive function
-     * @author Nick Shaforostoff <shafff@ukr.net>
+ * The class is used for keeping "global" params of recursive function
+ *
+ * @short Class for keeping "global" params of recursive function
+ * @author Nick Shaforostoff <shafff@ukr.net>
  */
 class LCSprinter
 {
 public:
     LCSprinter(const QStringList &s_1,
-               const QStringList& s_2,
+               const QStringList &s_2,
                QVector<LCSMarker> *b_,
                const uint nT_,
                uint index,
-               const QStringList& s1Space_,
-               const QStringList& s2Space_
-              );
+               const QStringList &s1Space_,
+               const QStringList &s2Space_);
     ~LCSprinter() = default;
 
     void printLCS(uint index);
@@ -74,32 +63,28 @@ private:
     QStringList s1Space, s2Space;
     QStringList::const_iterator it1, it2;
     QStringList::const_iterator it1Space, it2Space;
-    uint nT: 31; //we're using 1d vector as 2d
-    bool haveSpaces: 1; //"word: sfdfs" space is ": "
+    uint nT : 31; // we're using 1d vector as 2d
+    bool haveSpaces : 1; //"word: sfdfs" space is ": "
     QVector<LCSMarker> *b;
-    //QStringList::iterator it1Space, it2Space;
+    // QStringList::iterator it1Space, it2Space;
 };
 
-inline
-QStringList LCSprinter::operator()()
+inline QStringList LCSprinter::operator()()
 {
     QStringList result;
-    for (const QString& str : resultString)
+    for (const QString &str : resultString)
         result << str;
 
     return result;
 }
 
-
-inline
-LCSprinter::LCSprinter(const QStringList& s_1,
-                       const QStringList& s_2,
-                       QVector<LCSMarker> *b_,
-                       const uint nT_,
-                       uint index,
-                       const QStringList& s1Space_,
-                       const QStringList& s2Space_
-                      )
+inline LCSprinter::LCSprinter(const QStringList &s_1,
+                              const QStringList &s_2,
+                              QVector<LCSMarker> *b_,
+                              const uint nT_,
+                              uint index,
+                              const QStringList &s1Space_,
+                              const QStringList &s2Space_)
     : s1(s_1)
     , s2(s_2)
     , s1Space(s1Space_)
@@ -116,8 +101,7 @@ LCSprinter::LCSprinter(const QStringList& s_1,
     printLCS(index);
 }
 
-
-static QStringList prepareForInternalDiff(const QString& str)
+static QStringList prepareForInternalDiff(const QString &str)
 {
     QStringList result;
     int i = str.size();
@@ -129,7 +113,7 @@ static QStringList prepareForInternalDiff(const QString& str)
 
 void LCSprinter::printLCS(uint index)
 {
-    //fprintf(stderr,"%2d. %2d. %2d. %2d\n",(uint)(*b)[index],nT,index%nT, index);
+    // fprintf(stderr,"%2d. %2d. %2d. %2d\n",(uint)(*b)[index],nT,index%nT, index);
     if (index % nT == 0 || index < nT) {
         // original LCS algo does not have to deal with ins before first common
         uint bound = index % nT;
@@ -150,11 +134,11 @@ void LCSprinter::printLCS(uint index)
     if (ARROW_UP_LEFT == b->at(index)) {
         printLCS(index - nT - 1);
         if (it1 != s1.constEnd()) {
-            //qCWarning(LOKALIZE_LOG) << "upleft '" << *it1 <<"'";
-            //qCWarning(LOKALIZE_LOG) << "upleft 1s" << *it1Space;
-            //qCWarning(LOKALIZE_LOG) << "upleft 2s" << *it2Space;
+            // qCWarning(LOKALIZE_LOG) << "upleft '" << *it1 <<"'";
+            // qCWarning(LOKALIZE_LOG) << "upleft 1s" << *it1Space;
+            // qCWarning(LOKALIZE_LOG) << "upleft 2s" << *it2Space;
             if (haveSpaces) {
-                if ((*it1) == (*it2)) //case and accels
+                if ((*it1) == (*it2)) // case and accels
                     resultString.push_back(*it1);
                 else {
                     QStringList word1 = prepareForInternalDiff(*it1);
@@ -171,30 +155,33 @@ void LCSprinter::printLCS(uint index)
                     QStringList word2 = prepareForInternalDiff(*it2Space);
 
                     QStringList empty;
-                    //empty=calcLCS(word1,word2,empty,empty);
-//???this is not really good if we use diff result in autosubst
+                    // empty=calcLCS(word1,word2,empty,empty);
+                    //???this is not really good if we use diff result in autosubst
 
                     empty = calcLCS(word2, word1, empty, empty);
-                    empty.replaceInStrings(QStringLiteral("KBABELADD>"), QStringLiteral("KBABELTMP>"));
-                    empty.replaceInStrings(QStringLiteral("KBABELDEL>"), QStringLiteral("KBABELADD>"));
-                    empty.replaceInStrings(QStringLiteral("KBABELTMP>"), QStringLiteral("KBABELDEL>"));
+                    empty.replaceInStrings(addMarkerStart, QStringLiteral("{LokalizeTmp}"));
+                    empty.replaceInStrings(addMarkerEnd, QStringLiteral("{/LokalizeTmp}"));
+                    empty.replaceInStrings(delMarkerStart, addMarkerStart);
+                    empty.replaceInStrings(delMarkerEnd, addMarkerEnd);
+                    empty.replaceInStrings(QStringLiteral("{LokalizeTmp}"), delMarkerStart);
+                    empty.replaceInStrings(QStringLiteral("{/LokalizeTmp}"), delMarkerEnd);
 
                     resultString.push_back(empty.join(QString()));
                 }
                 ++it1Space;
                 ++it2Space;
-                //qCWarning(LOKALIZE_LOG) << " common " << *it1;
+                // qCWarning(LOKALIZE_LOG) << " common " << *it1;
             } else
-                resultString.push_back(*it1);//we may guess that this is a batch job, i.e. TM search
+                resultString.push_back(*it1); // we may guess that this is a batch job, i.e. TM search
             ++it1;
             ++it2;
         }
     } else if (ARROW_UP == b->at(index)) {
         printLCS(index - nT);
-//         if (it1!=s1.end())
+        //         if (it1!=s1.end())
         {
-            //qCWarning(LOKALIZE_LOG)<<"APPENDDEL "<<*it1;
-            //qCWarning(LOKALIZE_LOG)<<"APPENDDEL "<<*it1Space;
+            // qCWarning(LOKALIZE_LOG)<<"APPENDDEL "<<*it1;
+            // qCWarning(LOKALIZE_LOG)<<"APPENDDEL "<<*it1Space;
             resultString.push_back(delMarkerStart);
             resultString.push_back(*it1);
             ++it1;
@@ -210,7 +197,7 @@ void LCSprinter::printLCS(uint index)
         resultString.push_back(*it2);
         ++it2;
         if (haveSpaces) {
-            //qCWarning(LOKALIZE_LOG) << "add2 " << *it2;
+            // qCWarning(LOKALIZE_LOG) << "add2 " << *it2;
             resultString.push_back(*it2Space);
             ++it2Space;
         }
@@ -218,38 +205,30 @@ void LCSprinter::printLCS(uint index)
     }
 }
 
-
-
-
 // calculate the LCS
-QStringList calcLCS(const QStringList& s1Words,
-                    const QStringList& s2Words,
-                    const QStringList& s1Space,
-                    const QStringList& s2Space
-                   )
+QStringList calcLCS(const QStringList &s1Words, const QStringList &s2Words, const QStringList &s1Space, const QStringList &s2Space)
 {
-
     uint i;
     uint j;
 
     uint mX = s1Words.count();
     uint nY = s2Words.count();
 
-    //create lowered lists for matching,
-    //and use original ones for printing (but only for non-batch)
+    // create lowered lists for matching,
+    // and use original ones for printing (but only for non-batch)
     QStringList s1(s1Words);
     QStringList s2(s2Words);
 
     if (!s1Space.isEmpty()) {
-        //accels are only removed by batch jobs
-        //and this is not the one
-        //also, lower things a bit :)
+        // accels are only removed by batch jobs
+        // and this is not the one
+        // also, lower things a bit :)
 
         for (i = 0; i < mX; ++i)
             s1[i] = s1.at(i).toLower();
         for (i = 0; i < nY; ++i)
             s2[i] = s2.at(i).toLower();
-#if 0 //i'm too lazy...
+#if 0 // i'm too lazy...
         QString accel(Project::instance()->accel());
         i = mX;
         while (--i > 0) {
@@ -266,15 +245,12 @@ QStringList calcLCS(const QStringList& s1Words,
 #endif
     }
 
-
     uint mT = mX + 1;
     uint nT = nY + 1;
 
     QVector<LCSMarker> b(mT * nT, NOTHING);
     QVector<uint> c(mT * nT, 0);
 
-
-
     b[0] = FINAL;
     uint index_cache = 0;
     QStringList::const_iterator it1, it2;
@@ -300,7 +276,6 @@ QStringList calcLCS(const QStringList& s1Words,
     LCSprinter printer(s1Words, s2Words, &b, nT, index_cache, s1Space, s2Space);
 
     return printer();
-
 }
 
 QString wordDiff(QStringList s1, QStringList s2)
@@ -319,44 +294,28 @@ QString wordDiff(QStringList s1, QStringList s2)
 
     QString result = list.join(QString());
 
-
     if (!r)
         result.remove(0, 1);
-    result.remove(QStringLiteral("</KBABELADD><KBABELADD>"));
-    result.remove(QStringLiteral("</KBABELDEL><KBABELDEL>"));
+    result.remove(addMarkerEnd + addMarkerStart);
+    result.remove(delMarkerEnd + delMarkerStart);
 
     return result;
 }
 
-
-//this also separates punctuation marks etc from words as _only_ they may have changed
-static void prepareLists(QString str, QStringList& main, QStringList& space, const QString& accel, QString markup)
+// this also separates punctuation marks etc from words as _only_ they may have changed
+static void prepareLists(QString str, QStringList &main, QStringList &space, const QString &accel, QString markup)
 {
     Q_UNUSED(accel);
     int pos = 0;
 
-    //accels are only removed by batch jobs
-    //and this is not the one
-#if 0
-    QRegExp rxAccelInWord("[^\\W|\\d]" + accel + "[^\\W|\\d]");
-    int accelLen = accel.size();
-    while ((pos = rxAccelInWord.indexIn(str, pos)) != -1) {
-        str.remove(rxAccelInWord.pos() + 1, accelLen);
-        pos += 2; //two letters
-    }
-#endif
-
-    //QRegExp rxSplit("\\W+|\\d+");
-    //i tried that but it failed:
     if (!markup.isEmpty())
         markup += QLatin1Char('|');
     const QRegularExpression rxSplit(QLatin1String("(\x08?") + markup + QLatin1String("\\W+|\\d+)+"));
 
     main = str.split(rxSplit, Qt::SkipEmptyParts);
-    main.prepend(QStringLiteral("\t"));//little hack
+    main.prepend(QStringLiteral("\t")); // little hack
 
-
-    //ensure the string always begins with the space part
+    // ensure the string always begins with the space part
     str.prepend(QStringLiteral("\b"));
     pos = 0;
     while (true) {
@@ -368,23 +327,19 @@ static void prepareLists(QString str, QStringList& main, QStringList& space, con
         space.append(match.captured(0));
         pos += match.capturedLength();
     }
-    space.append(QString());//so we don't have to worry about list boundaries
-    space.append(QString());//so we don't have to worry about list boundaries
+    space.append(QString()); // so we don't have to worry about list boundaries
+    space.append(QString()); // so we don't have to worry about list boundaries
 }
 
-QString userVisibleWordDiff(const QString& str1ForMatching,
-                            const QString& str2ForMatching,
-                            const QString& accel,
-                            const QString& markup,
-                            int options)
+QString userVisibleWordDiff(const QString &str1ForMatching, const QString &str2ForMatching, const QString &accel, const QString &markup, int options)
 {
     QString res;
     if (str1ForMatching.isEmpty() && str2ForMatching.isEmpty()) {
         return res;
     } else if (!str1ForMatching.isEmpty() && str2ForMatching.isEmpty()) {
-        res = QLatin1String("{KBABELDEL}") + str1ForMatching + QLatin1String("{/KBABELDEL}");
+        res = delMarkerStart + str1ForMatching + delMarkerEnd;
     } else if (str1ForMatching.isEmpty() && !str2ForMatching.isEmpty()) {
-        res = QLatin1String("{KBABELADD}") + str2ForMatching + QLatin1String("{/KBABELADD}");
+        res = addMarkerStart + str2ForMatching + addMarkerEnd;
     } else {
         QStringList s1, s2;
         QStringList s1Space, s2Space;
@@ -393,15 +348,10 @@ QString userVisibleWordDiff(const QString& str1ForMatching,
         prepareLists(str2ForMatching, s2, s2Space, accel, markup);
 
         QStringList result(calcLCS(s1, s2, s1Space, s2Space));
-        result.removeFirst();//\t
+        result.removeFirst(); //\t
         result.first().remove(0, 1); //\b
-        result.replaceInStrings(QStringLiteral("<KBABELDEL></KBABELDEL>"), QString());
-        result.replaceInStrings(QStringLiteral("<KBABELADD></KBABELADD>"), QString());
-
-        result.replaceInStrings(QStringLiteral("<KBABELADD>"), QStringLiteral("{KBABELADD}"));
-        result.replaceInStrings(QStringLiteral("</KBABELADD>"), QStringLiteral("{/KBABELADD}"));
-        result.replaceInStrings(QStringLiteral("<KBABELDEL>"), QStringLiteral("{KBABELDEL}"));
-        result.replaceInStrings(QStringLiteral("</KBABELDEL>"), QStringLiteral("{/KBABELDEL}"));
+        result.replaceInStrings(delMarkerStart + delMarkerEnd, QString());
+        result.replaceInStrings(addMarkerStart + addMarkerEnd, QString());
 
         if (options & Html) {
             result.replaceInStrings(QStringLiteral("&"), QStringLiteral("&amp;"));
@@ -409,18 +359,51 @@ QString userVisibleWordDiff(const QString& str1ForMatching,
             result.replaceInStrings(QStringLiteral(">"), QStringLiteral("&gt;"));
         }
         res = result.join(QString());
-        res.remove(QStringLiteral("{/KBABELADD}{KBABELADD}"));
-        res.remove(QStringLiteral("{/KBABELDEL}{KBABELDEL}"));
+        res.remove(addMarkerEnd + addMarkerStart);
+        res.remove(delMarkerEnd + delMarkerStart);
     }
 
-    if (options & Html) {
-        res.replace(QLatin1String("{KBABELADD}"), QLatin1String("<font style=\"background-color:") + Settings::addColor().name() + QLatin1String(";color:black\">"));
-        res.replace(QLatin1String("{/KBABELADD}"), QLatin1String("</font>"));
-        res.replace(QLatin1String("{KBABELDEL}"), QLatin1String("<font style=\"background-color:") + Settings::delColor().name() + QLatin1String(";color:black\">"));
-        res.replace(QLatin1String("{/KBABELDEL}"), QLatin1String("</font>"));
-        res.replace(QLatin1String("\\n"), QLatin1String("\\n<br>"));
-    }
+    // Convert from curly brace diff tags to HTML coloured with inline CSS
+    if (options & Html)
+        res = diffToHtmlDiff(res);
 
     return res;
 }
 
+QString diffToHtmlDiff(const QString &diff)
+{
+    // TODO: To improve this code, the hex colour generation could
+    // be moved out of this function so that it is not calculated
+    // every time this function is called. Bear in mind that it
+    // should be updated when the user changes colour scheme:
+    // perhaps reading how syntaxhighlighter.cpp works would be
+    // useful as reference, and looking at using KStatefulBrush?
+    QString coloredHtmlDiff;
+
+    QString addDiffColorSpan;
+    QString delDiffColorSpan;
+    QTextCharFormat addDiffColor;
+    QTextCharFormat delDiffColor;
+
+    coloredHtmlDiff = diff;
+
+    KColorScheme colorScheme(QPalette::Normal);
+    addDiffColor.setForeground(colorScheme.foreground(KColorScheme::PositiveText));
+    addDiffColor.setBackground(colorScheme.background(KColorScheme::PositiveBackground));
+    delDiffColor.setForeground(colorScheme.foreground(KColorScheme::NegativeText));
+    delDiffColor.setBackground(colorScheme.background(KColorScheme::NegativeBackground));
+    // Note: the span classes below are used by tmview.cpp TM::targetAdapted() regex, but not elsewhere
+    addDiffColorSpan = QLatin1String("<span class=\"lokalizeAddDiffColorSpan\" style=\"background-color:") + addDiffColor.background().color().name()
+        + QLatin1String(";color:") + addDiffColor.foreground().color().name() + QLatin1String(";\">");
+    delDiffColorSpan = QLatin1String("<span class=\"lokalizeDelDiffColorSpan\" style=\"background-color:") + delDiffColor.background().color().name()
+        + QLatin1String(";color:") + delDiffColor.foreground().color().name() + QLatin1String(";\">");
+
+    coloredHtmlDiff.replace(addMarkerStart, addDiffColorSpan);
+    coloredHtmlDiff.replace(addMarkerEnd, QLatin1String("</span>"));
+    coloredHtmlDiff.replace(delMarkerStart, delDiffColorSpan);
+    coloredHtmlDiff.replace(delMarkerEnd, QLatin1String("</span>"));
+    // Newline chars that are manual line breaks in the translation file are converted to HTML
+    coloredHtmlDiff.replace(QLatin1String("\n"), QLatin1String("<br>"));
+
+    return coloredHtmlDiff;
+}
