@@ -11,61 +11,59 @@
 
 #include "lokalize_debug.h"
 
-#include "ui_queryoptions.h"
-#include "project.h"
 #include "dbfilesmodel.h"
-#include "tmscanapi.h"
-#include "qaview.h"
-#include "prefs_lokalize.h"
-#include "jobs.h"
 #include "fastsizehintitemdelegate.h"
+#include "jobs.h"
+#include "prefs_lokalize.h"
+#include "project.h"
+#include "qaview.h"
+#include "tmscanapi.h"
+#include "ui_queryoptions.h"
 
 #include <QApplication>
-#include <QTreeView>
-#include <QSqlQueryModel>
-#include <QSqlQuery>
-#include <QSqlRecord>
 #include <QButtonGroup>
 #include <QClipboard>
-#include <QShortcut>
 #include <QDragEnterEvent>
 #include <QFile>
 #include <QMimeData>
+#include <QShortcut>
 #include <QSortFilterProxyModel>
-#include <QStyledItemDelegate>
+#include <QSqlQuery>
+#include <QSqlRecord>
 #include <QStringBuilder>
-#include <QTextDocument>
 #include <QStringListModel>
+#include <QStyledItemDelegate>
+#include <QTextDocument>
+#include <QTreeView>
 
 #include <KActionCategory>
 #include <KColorScheme>
-#include <KXMLGUIFactory>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KXMLGUIFactory>
 
 #if defined(Q_OS_WIN) && defined(QStringLiteral)
 #undef QStringLiteral
 #define QStringLiteral QLatin1String
 #endif
 
-
 using namespace TM;
-//static int BIG_COUNTER=0;
+// static int BIG_COUNTER=0;
 
-//TODO do things for case when user explicitly wants to find & accel mark
+// TODO do things for case when user explicitly wants to find & accel mark
 
-//BEGIN TMDBModel
-TMDBModel::TMDBModel(QObject* parent)
+// BEGIN TMDBModel
+TMDBModel::TMDBModel(QObject *parent)
     : QSqlQueryModel(parent)
 {
-    setHeaderData(TMDBModel::Source,            Qt::Horizontal, i18nc("@title:column Original text", "Source"));
-    setHeaderData(TMDBModel::Target,            Qt::Horizontal, i18nc("@title:column Text in target language", "Target"));
-    setHeaderData(TMDBModel::Context,           Qt::Horizontal, i18nc("@title:column", "Context"));
-    setHeaderData(TMDBModel::Filepath,          Qt::Horizontal, i18nc("@title:column", "File"));
-    setHeaderData(TMDBModel::TransationStatus,  Qt::Horizontal, i18nc("@title:column", "Translation Status"));
+    setHeaderData(TMDBModel::Source, Qt::Horizontal, i18nc("@title:column Original text", "Source"));
+    setHeaderData(TMDBModel::Target, Qt::Horizontal, i18nc("@title:column Text in target language", "Target"));
+    setHeaderData(TMDBModel::Context, Qt::Horizontal, i18nc("@title:column", "Context"));
+    setHeaderData(TMDBModel::Filepath, Qt::Horizontal, i18nc("@title:column", "File"));
+    setHeaderData(TMDBModel::TransationStatus, Qt::Horizontal, i18nc("@title:column", "Translation Status"));
 }
 
-void TMDBModel::setDB(const QString& str)
+void TMDBModel::setDB(const QString &str)
 {
     m_dbName = str;
 
@@ -85,27 +83,35 @@ void TMDBModel::setQueryType(int type)
     m_queryType = (QueryType)type;
 }
 
-void TMDBModel::setFilter(const QString& source, const QString& target,
-                          bool invertSource, bool invertTarget,
-                          const QString& filemask
-                         )
+void TMDBModel::setFilter(const QString &source, const QString &target, bool invertSource, bool invertTarget, const QString &filemask)
 {
-    QString escapedSource(source); escapedSource.replace(QLatin1Char('\''), QStringLiteral("''"));
-    QString escapedTarget(target); escapedTarget.replace(QLatin1Char('\''), QStringLiteral("''"));
-    QString invertSourceStr; if (invertSource) invertSourceStr = QStringLiteral("NOT ");
-    QString invertTargetStr; if (invertTarget) invertTargetStr = QStringLiteral("NOT ");
-    QString escapedFilemask(filemask); escapedFilemask.replace(QLatin1Char('\''), QStringLiteral("''"));
+    QString escapedSource(source);
+    escapedSource.replace(QLatin1Char('\''), QStringLiteral("''"));
+    QString escapedTarget(target);
+    escapedTarget.replace(QLatin1Char('\''), QStringLiteral("''"));
+    QString invertSourceStr;
+    if (invertSource)
+        invertSourceStr = QStringLiteral("NOT ");
+    QString invertTargetStr;
+    if (invertTarget)
+        invertTargetStr = QStringLiteral("NOT ");
+    QString escapedFilemask(filemask);
+    escapedFilemask.replace(QLatin1Char('\''), QStringLiteral("''"));
     QString sourceQuery;
     QString targetQuery;
     QString fileQuery;
 
     if (m_queryType == SubStr) {
-        escapedSource.replace(QLatin1Char('%'), QStringLiteral("\b%")); escapedSource.replace(QLatin1Char('_'), QStringLiteral("\b_"));
-        escapedTarget.replace(QLatin1Char('%'), QStringLiteral("\b%")); escapedTarget.replace(QLatin1Char('_'), QStringLiteral("\b_"));
+        escapedSource.replace(QLatin1Char('%'), QStringLiteral("\b%"));
+        escapedSource.replace(QLatin1Char('_'), QStringLiteral("\b_"));
+        escapedTarget.replace(QLatin1Char('%'), QStringLiteral("\b%"));
+        escapedTarget.replace(QLatin1Char('_'), QStringLiteral("\b_"));
         if (!escapedSource.isEmpty())
-            sourceQuery = QStringLiteral("AND source_strings.source ") + invertSourceStr + QStringLiteral("LIKE '%") + escapedSource + QStringLiteral("%' ESCAPE '\b' ");
+            sourceQuery =
+                QStringLiteral("AND source_strings.source ") + invertSourceStr + QStringLiteral("LIKE '%") + escapedSource + QStringLiteral("%' ESCAPE '\b' ");
         if (!escapedTarget.isEmpty())
-            targetQuery = QStringLiteral("AND target_strings.target ") + invertTargetStr + QStringLiteral("LIKE '%") + escapedTarget + QStringLiteral("%' ESCAPE '\b' ");
+            targetQuery =
+                QStringLiteral("AND target_strings.target ") + invertTargetStr + QStringLiteral("LIKE '%") + escapedTarget + QStringLiteral("%' ESCAPE '\b' ");
     } else if (m_queryType == WordOrder) {
         /*escapedSource.replace('%',"\b%");escapedSource.replace('_',"\b_");
         escapedTarget.replace('%',"\b%");escapedTarget.replace('_',"\b_");*/
@@ -115,37 +121,35 @@ void TMDBModel::setFilter(const QString& source, const QString& target,
 
         if (!sourceList.isEmpty())
             sourceQuery = QStringLiteral("AND source_strings.source ") + invertSourceStr + QStringLiteral("LIKE '%")
-                          + sourceList.join(QStringLiteral("%' AND source_strings.source ") + invertSourceStr + QStringLiteral("LIKE '%")) + QStringLiteral("%' ");
+                + sourceList.join(QStringLiteral("%' AND source_strings.source ") + invertSourceStr + QStringLiteral("LIKE '%")) + QStringLiteral("%' ");
         if (!targetList.isEmpty())
             targetQuery = QStringLiteral("AND target_strings.target ") + invertTargetStr + QStringLiteral("LIKE '%")
-                          + targetList.join(QStringLiteral("%' AND target_strings.target ") + invertTargetStr + QStringLiteral("LIKE '%")) + QStringLiteral("%' ");
+                + targetList.join(QStringLiteral("%' AND target_strings.target ") + invertTargetStr + QStringLiteral("LIKE '%")) + QStringLiteral("%' ");
     } else {
         if (!escapedSource.isEmpty())
             sourceQuery = QStringLiteral("AND source_strings.source ") + invertSourceStr + QStringLiteral("GLOB '") + escapedSource + QStringLiteral("' ");
         if (!escapedTarget.isEmpty())
             targetQuery = QStringLiteral("AND target_strings.target ") + invertTargetStr + QStringLiteral("GLOB '") + escapedTarget + QStringLiteral("' ");
-
     }
     if (!filemask.isEmpty())
         fileQuery = QStringLiteral("AND files.path GLOB '") + escapedFilemask + QStringLiteral("' ");
 
-    QString fromPart = QStringLiteral("FROM main JOIN source_strings ON (source_strings.id=main.source) "
-                                      "JOIN target_strings ON (target_strings.id=main.target), files "
-                                      "WHERE files.id=main.file ")
-                       + sourceQuery
-                       + targetQuery
-                       + fileQuery;
+    QString fromPart = QStringLiteral(
+                           "FROM main JOIN source_strings ON (source_strings.id=main.source) "
+                           "JOIN target_strings ON (target_strings.id=main.target), files "
+                           "WHERE files.id=main.file ")
+        + sourceQuery + targetQuery + fileQuery;
 
-    ExecQueryJob* job = new ExecQueryJob(QStringLiteral(
-            "SELECT source_strings.source, target_strings.target, "
-            "main.ctxt, files.path, "
-            "source_strings.source_accel, target_strings.target_accel, main.bits ")
-                                         + fromPart, m_dbName, &m_dbOperationMutex);
+    ExecQueryJob *job = new ExecQueryJob(QStringLiteral("SELECT source_strings.source, target_strings.target, "
+                                                        "main.ctxt, files.path, "
+                                                        "source_strings.source_accel, target_strings.target_accel, main.bits ")
+                                             + fromPart,
+                                         m_dbName,
+                                         &m_dbOperationMutex);
 
     connect(job, &ExecQueryJob::done, this, &TMDBModel::slotQueryExecuted);
     threadPool()->start(job);
 
-
     job = new ExecQueryJob(QStringLiteral("SELECT count(*) ") + fromPart, m_dbName, &m_dbOperationMutex);
     connect(job, &ExecQueryJob::done, this, &TMDBModel::slotQueryExecuted);
     threadPool()->start(job);
@@ -153,22 +157,20 @@ void TMDBModel::setFilter(const QString& source, const QString& target,
     m_totalResultCount = 0;
 }
 
-void TMDBModel::slotQueryExecuted(ExecQueryJob* job)
+void TMDBModel::slotQueryExecuted(ExecQueryJob *job)
 {
     job->deleteLater();
     m_dbOperationMutex.lock();
 
     if (job->query->lastQuery().startsWith(QLatin1String("SELECT count(*) "))) {
-
         m_totalResultCount = job->query->next() ? job->query->value(0).toInt() : -1;
         m_dbOperationMutex.unlock();
         Q_EMIT finalResultCountFetched(m_totalResultCount);
         return;
     }
-    setQuery(*(job->query));
+    setQuery(std::move(*job->query));
     m_dbOperationMutex.unlock();
     Q_EMIT resultsFetched();
-
 }
 
 bool TMDBModel::rowIsApproved(int row) const
@@ -178,22 +180,22 @@ bool TMDBModel::rowIsApproved(int row) const
     return !(ok && bits & 4);
 }
 
-int TMDBModel::translationStatus(const QModelIndex& item) const
+int TMDBModel::translationStatus(const QModelIndex &item) const
 {
-    //QMutexLocker locker(&m_dbOperationMutex);
+    // QMutexLocker locker(&m_dbOperationMutex);
     if (QSqlQueryModel::data(item.sibling(item.row(), Target), Qt::DisplayRole).toString().isEmpty())
         return 2;
     return int(!rowIsApproved(item.row()));
 }
 
 #define TM_DELIMITER '\v'
-QVariant TMDBModel::data(const QModelIndex& item, int role) const
+QVariant TMDBModel::data(const QModelIndex &item, int role) const
 {
-    //QMutexLocker locker(&m_dbOperationMutex);
+    // QMutexLocker locker(&m_dbOperationMutex);
     bool doHtml = (role == FastSizeHintItemDelegate::HtmlDisplayRole);
     if (doHtml)
         role = Qt::DisplayRole;
-    else if (role == Qt::FontRole && item.column() == TMDBModel::Target) { //TODO Qt::ForegroundRole -- brush for orphaned entries
+    else if (role == Qt::FontRole && item.column() == TMDBModel::Target) { // TODO Qt::ForegroundRole -- brush for orphaned entries
         QFont font = QApplication::font();
         font.setItalic(!rowIsApproved(item.row()));
         return font;
@@ -208,13 +210,13 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
     if (role != Qt::DisplayRole)
         return result;
 
-    if (item.column() == TMDBModel::Context) { //context
+    if (item.column() == TMDBModel::Context) { // context
         QString r = result.toString();
         int pos = r.indexOf(QLatin1Char(TM_DELIMITER));
         if (pos != -1)
             result = r.remove(pos, r.size());
-    } else if (item.column() < TMDBModel::Context && !record(item.row()).isNull(TMDBModel::_SourceAccel + item.column())) { //source, target
-        const QVariant& posVar = record(item.row()).value(TMDBModel::_SourceAccel + item.column());
+    } else if (item.column() < TMDBModel::Context && !record(item.row()).isNull(TMDBModel::_SourceAccel + item.column())) { // source, target
+        const QVariant &posVar = record(item.row()).value(TMDBModel::_SourceAccel + item.column());
         int pos = -1;
         bool ok = false;
         if (posVar.isValid())
@@ -229,8 +231,7 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
     } else if (item.column() == TMDBModel::TransationStatus) {
         static const QString statuses[] = {i18nc("@info:status 'non-fuzzy' in gettext terminology", "Ready"),
                                            i18nc("@info:status 'fuzzy' in gettext terminology", "Needs review"),
-                                           i18nc("@info:status", "Untranslated")
-                                          };
+                                           i18nc("@info:status", "Untranslated")};
         return statuses[translationStatus(item)];
     }
     if (doHtml && item.column() < TMDBModel::Context)
@@ -239,30 +240,31 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
         return result;
 }
 
-//END TMDBModel
+// END TMDBModel
 
-//BEGIN TMResultsSortFilterProxyModel
-class TMResultsSortFilterProxyModel: public QSortFilterProxyModel
+// BEGIN TMResultsSortFilterProxyModel
+class TMResultsSortFilterProxyModel : public QSortFilterProxyModel
 {
 public:
     explicit TMResultsSortFilterProxyModel(QObject *parent)
         : QSortFilterProxyModel(parent)
-    {}
-    void setRules(const QVector<Rule>& rules);
-    void fetchMore(const QModelIndex& parent) override;
-    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+    {
+    }
+    void setRules(const QVector<Rule> &rules);
+    void fetchMore(const QModelIndex &parent) override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
 protected:
-    bool lessThan(const QModelIndex& left, const QModelIndex& right) const override;
-    bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const override;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
     QVector<Rule> m_rules;
     mutable QMap<int, int> m_matchingRulesForSourceRow;
-    //mutable QMap<int, QVector<StartLen> > m_highlightDataForSourceRow;
+    // mutable QMap<int, QVector<StartLen> > m_highlightDataForSourceRow;
 };
 
-bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex& left, const QModelIndex& right) const
+bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
     if (left.column() == TMDBModel::TransationStatus) {
         const int l = left.data(TMDBModel::TransStateRole).toInt();
@@ -272,7 +274,7 @@ bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex& left, const QMod
     return QSortFilterProxyModel::lessThan(left, right);
 }
 
-void TMResultsSortFilterProxyModel::fetchMore(const QModelIndex& parent)
+void TMResultsSortFilterProxyModel::fetchMore(const QModelIndex &parent)
 {
     int oldSourceRowCount = sourceModel()->rowCount();
     int oldRowCount = rowCount();
@@ -291,14 +293,14 @@ void TMResultsSortFilterProxyModel::fetchMore(const QModelIndex& parent)
     Q_EMIT layoutChanged();
 }
 
-void TMResultsSortFilterProxyModel::setRules(const QVector<Rule>& rules)
+void TMResultsSortFilterProxyModel::setRules(const QVector<Rule> &rules)
 {
     m_rules = rules;
     m_matchingRulesForSourceRow.clear();
     invalidateFilter();
 }
 
-QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role) const
+QVariant TMResultsSortFilterProxyModel::data(const QModelIndex &index, int role) const
 {
     QVariant result = QSortFilterProxyModel::data(index, role);
 
@@ -311,24 +313,21 @@ QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role)
     int source_row = mapToSource(index).row();
     QString string = result.toString();
 
-    const QVector<QRegularExpression> regExps =
-        (index.column() == TMDBModel::Source) ?
-            m_rules[m_matchingRulesForSourceRow[source_row]].sources
-        :
-            m_rules[m_matchingRulesForSourceRow[source_row]].falseFriends;
+    const QVector<QRegularExpression> regExps = (index.column() == TMDBModel::Source) ? m_rules[m_matchingRulesForSourceRow[source_row]].sources
+                                                                                      : m_rules[m_matchingRulesForSourceRow[source_row]].falseFriends;
 
-    for (const auto& re : regExps) {
+    for (const auto &re : regExps) {
         const auto match = re.match(string);
         if (match.hasMatch())
             return string.replace(match.capturedStart(), match.capturedLength(), QStringLiteral("<b>") + match.capturedView(0) + QStringLiteral("</b>"));
     }
 
-    //StartLen sl=m_highlightDataForSourceRow.value(source_row).at(index.column());
+    // StartLen sl=m_highlightDataForSourceRow.value(source_row).at(index.column());
 
     return result;
 }
 
-bool TMResultsSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex& source_parent) const
+bool TMResultsSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
     if (m_rules.isEmpty())
         return true;
@@ -344,44 +343,43 @@ bool TMResultsSortFilterProxyModel::filterAcceptsRow(int source_row, const QMode
 
     return accept;
 }
-//END TMResultsSortFilterProxyModel
+// END TMResultsSortFilterProxyModel
 
-class QueryStylesModel: public QStringListModel
+class QueryStylesModel : public QStringListModel
 {
 public:
-    explicit QueryStylesModel(QObject* parent = nullptr);
-    QVariant data(const QModelIndex& item, int role) const override;
+    explicit QueryStylesModel(QObject *parent = nullptr);
+    QVariant data(const QModelIndex &item, int role) const override;
 };
 
-QueryStylesModel::QueryStylesModel(QObject* parent): QStringListModel(parent)
+QueryStylesModel::QueryStylesModel(QObject *parent)
+    : QStringListModel(parent)
 {
     setStringList(QStringList(i18n("Substring")) << i18n("Google-like") << i18n("Wildcard"));
 }
 
-QVariant QueryStylesModel::data(const QModelIndex& item, int role) const
+QVariant QueryStylesModel::data(const QModelIndex &item, int role) const
 {
     if (role == Qt::ToolTipRole) {
         static const QString tooltips[] = {i18n("Case insensitive"),
                                            i18n("Space is AND operator. Case insensitive."),
-                                           i18n("Shell globs (* and ?). Case sensitive.")
-                                          };
+                                           i18n("Shell globs (* and ?). Case sensitive.")};
         return tooltips[item.row()];
     }
     return QStringListModel::data(item, role);
 }
 
-
-//BEGIN TMWindow
+// BEGIN TMWindow
 TMTab::TMTab(QWidget *parent)
     : LokalizeSubwindowBase2(parent)
     , m_proxyModel(new TMResultsSortFilterProxyModel(this))
 {
-    //setCaption(i18nc("@title:window","Translation Memory"),false);
+    // setCaption(i18nc("@title:window","Translation Memory"),false);
     setWindowTitle(i18nc("@title:window", "Translation Memory"));
     setAcceptDrops(true);
 
     ui_queryOptions = new Ui_QueryOptions;
-    QWidget* w = new QWidget(this);
+    QWidget *w = new QWidget(this);
     ui_queryOptions->setupUi(w);
     setCentralWidget(w);
     ui_queryOptions->queryLayout->setStretchFactor(ui_queryOptions->mainQueryLayout, 42);
@@ -392,14 +390,14 @@ TMTab::TMTab(QWidget *parent)
     connect(ui_queryOptions->doFind, &QPushButton::clicked, this, &TMTab::performQuery);
     connect(ui_queryOptions->doUpdateTM, &QPushButton::clicked, this, &TMTab::updateTM);
 
-    QShortcut* sh = new QShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_L), this);
+    QShortcut *sh = new QShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_L), this);
     connect(sh, &QShortcut::activated, ui_queryOptions->querySource, qOverload<>(&QLineEdit::setFocus));
     setFocusProxy(ui_queryOptions->querySource);
 
-    QTreeView* view = ui_queryOptions->treeView;
+    QTreeView *view = ui_queryOptions->treeView;
     view->setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    QAction* a = new QAction(i18n("Copy source to clipboard"), view);
+    QAction *a = new QAction(i18n("Copy source to clipboard"), view);
     a->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_S));
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(a, &QAction::triggered, this, &TMTab::copySource);
@@ -418,10 +416,10 @@ TMTab::TMTab(QWidget *parent)
     connect(view, &QTreeView::activated, this, &TMTab::openFile);
     view->addAction(a);
 
-    //view->addAction(KStandardAction::copy(this),this,SLOT(),this);
-    //QKeySequence::Copy?
-    //QShortcut* shortcut = new QShortcut(Qt::ControlModifier | Qt::Key_P,view,0,0,Qt::WidgetWithChildrenShortcut);
-    //connect(shortcut,SIGNAL(activated()), this, SLOT(copyText()));
+    // view->addAction(KStandardAction::copy(this),this,SLOT(),this);
+    // QKeySequence::Copy?
+    // QShortcut* shortcut = new QShortcut(Qt::ControlModifier | Qt::Key_P,view,0,0,Qt::WidgetWithChildrenShortcut);
+    // connect(shortcut,SIGNAL(activated()), this, SLOT(copyText()));
 
     m_model = new TMDBModel(this);
     m_model->setDB(Project::instance()->projectID());
@@ -444,12 +442,11 @@ TMTab::TMTab(QWidget *parent)
     richTextColumns[TMDBModel::Source] = true;
     richTextColumns[TMDBModel::Target] = true;
     view->setItemDelegate(new FastSizeHintItemDelegate(this, singleLineColumns, richTextColumns));
-    connect(m_model, &TMDBModel::resultsFetched, (FastSizeHintItemDelegate*)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
-    connect(m_model, &TMDBModel::modelReset, (FastSizeHintItemDelegate*)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
-    connect(m_proxyModel, &TMResultsSortFilterProxyModel::layoutChanged, (FastSizeHintItemDelegate*)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
+    connect(m_model, &TMDBModel::resultsFetched, (FastSizeHintItemDelegate *)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
+    connect(m_model, &TMDBModel::modelReset, (FastSizeHintItemDelegate *)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
+    connect(m_proxyModel, &TMResultsSortFilterProxyModel::layoutChanged, (FastSizeHintItemDelegate *)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
     connect(m_proxyModel, &TMResultsSortFilterProxyModel::layoutChanged, this, &TMTab::displayTotalResultCount);
 
-
     connect(m_model, &TMDBModel::resultsFetched, this, &TMTab::handleResults);
     connect(m_model, &TMDBModel::finalResultCountFetched, this, &TMTab::displayTotalResultCount);
 
@@ -464,18 +461,20 @@ TMTab::TMTab(QWidget *parent)
         ui_queryOptions->dbName->setCurrentIndex(pos);
     }
     const auto combo = ui_queryOptions->dbName;
-    connect(combo, qOverload<int>(&QComboBox::currentIndexChanged),
-            m_model, [this, combo](const int index) {
+    connect(combo, qOverload<int>(&QComboBox::currentIndexChanged), m_model, [this, combo](const int index) {
         m_model->setDB(combo->itemText(index));
     });
 
-//BEGIN resizeColumnToContents
-    static const int maxInitialWidths[4] = {QGuiApplication::primaryScreen()->availableGeometry().width() / 3, QGuiApplication::primaryScreen()->availableGeometry().width() / 3, 50, 200};
+    // BEGIN resizeColumnToContents
+    static const int maxInitialWidths[4] = {QGuiApplication::primaryScreen()->availableGeometry().width() / 3,
+                                            QGuiApplication::primaryScreen()->availableGeometry().width() / 3,
+                                            50,
+                                            200};
     int column = sizeof(maxInitialWidths) / sizeof(int);
     while (--column >= 0)
         view->setColumnWidth(column, maxInitialWidths[column]);
 
-//END resizeColumnToContents
+    // END resizeColumnToContents
 
     int i = 6;
     while (--i > ID_STATUS_PROGRESS)
@@ -485,10 +484,9 @@ TMTab::TMTab(QWidget *parent)
     setUpdatedXMLFile();
     dbusObjectPath();
 
-
     QAction *action;
-    KActionCollection* ac = actionCollection();
-    KActionCategory* tm = new KActionCategory(i18nc("@title actions category", "Translation Memory"), ac);
+    KActionCollection *ac = actionCollection();
+    KActionCategory *tm = new KActionCategory(i18nc("@title actions category", "Translation Memory"), ac);
 
     action = tm->addAction(QStringLiteral("tools_tm_manage"), Project::instance(), SLOT(showTMManager()));
     action->setText(i18nc("@action:inmenu", "Manage translation memories"));
@@ -501,7 +499,6 @@ TMTab::TMTab(QWidget *parent)
     connect(m_qaView, &QaView::rulesChanged, this, qOverload<>(&TMTab::setQAMode));
     connect(m_qaView->toggleViewAction(), &QAction::toggled, this, qOverload<bool>(&TMTab::setQAMode));
 
-
     KConfig config;
     KConfigGroup cg(&config, QStringLiteral("MainWindow"));
     view->header()->restoreState(QByteArray::fromBase64(cg.readEntry("TMSearchResultsHeaderState", QByteArray())));
@@ -522,7 +519,7 @@ void TMTab::updateTM()
 {
     scanRecursive(QStringList(Project::instance()->poDir()), Project::instance()->projectID());
     if (Settings::deleteFromTMOnMissing()) {
-        RemoveMissingFilesJob* job = new RemoveMissingFilesJob(Project::instance()->projectID());
+        RemoveMissingFilesJob *job = new RemoveMissingFilesJob(Project::instance()->projectID());
         TM::threadPool()->start(job, REMOVEMISSINGFILES);
     }
 }
@@ -532,13 +529,14 @@ void TMTab::performQuery()
     if (ui_queryOptions->dbName->currentText().isEmpty()) {
         int pos = ui_queryOptions->dbName->findData(Project::instance()->projectID(), DBFilesModel::NameRole);
         if (pos >= 0)
-            ui_queryOptions->dbName->setCurrentIndex(pos); //m_model->setDB(Project::instance()->projectID());
+            ui_queryOptions->dbName->setCurrentIndex(pos); // m_model->setDB(Project::instance()->projectID());
     }
     m_model->m_dbOperationMutex.lock();
-    m_model->setFilter(ui_queryOptions->querySource->text(), ui_queryOptions->queryTarget->text(),
-                       ui_queryOptions->invertSource->isChecked(), ui_queryOptions->invertTarget->isChecked(),
-                       ui_queryOptions->filemask->text()
-                      );
+    m_model->setFilter(ui_queryOptions->querySource->text(),
+                       ui_queryOptions->queryTarget->text(),
+                       ui_queryOptions->invertSource->isChecked(),
+                       ui_queryOptions->invertTarget->isChecked(),
+                       ui_queryOptions->filemask->text());
     m_model->m_dbOperationMutex.unlock();
     QApplication::setOverrideCursor(Qt::BusyCursor);
 }
@@ -547,13 +545,13 @@ void TMTab::handleResults()
 {
     QApplication::restoreOverrideCursor();
     QString filemask = ui_queryOptions->filemask->text();
-    //ui_queryOptions->regexSource->text(),ui_queryOptions->regexTarget->text()
+    // ui_queryOptions->regexSource->text(),ui_queryOptions->regexTarget->text()
     m_model->m_dbOperationMutex.lock();
     int rowCount = m_model->rowCount();
     m_model->m_dbOperationMutex.unlock();
     if (rowCount == 0) {
         qCDebug(LOKALIZE_LOG) << "m_model->rowCount()==0";
-        //try harder
+        // try harder
         if (m_partToAlsoTryLater != DocPosition::UndefPart) {
             if (m_partToAlsoTryLater == DocPosition::Comment) {
                 QString text = ui_queryOptions->queryTarget->text();
@@ -565,12 +563,12 @@ void TMTab::handleResults()
                     findGuiText(text);
                 return;
             }
-            QLineEdit* const source_target_query[] = {ui_queryOptions->queryTarget, ui_queryOptions->querySource};
+            QLineEdit *const source_target_query[] = {ui_queryOptions->queryTarget, ui_queryOptions->querySource};
             source_target_query[m_partToAlsoTryLater == DocPosition::Source]->setText(source_target_query[m_partToAlsoTryLater != DocPosition::Source]->text());
             source_target_query[m_partToAlsoTryLater != DocPosition::Source]->clear();
-            m_partToAlsoTryLater = ui_queryOptions->filemask->text().isEmpty() ?
-                                   DocPosition::UndefPart :
-                                   DocPosition::Comment;  //leave a note that we should also try w/o package if the current one doesn't succeed
+            m_partToAlsoTryLater = ui_queryOptions->filemask->text().isEmpty()
+                ? DocPosition::UndefPart
+                : DocPosition::Comment; // leave a note that we should also try w/o package if the current one doesn't succeed
             return performQuery();
         }
         if (!filemask.isEmpty() && !filemask.contains(QLatin1Char('*'))) {
@@ -596,9 +594,10 @@ void TMTab::displayTotalResultCount()
     m_model->m_dbOperationMutex.unlock();
 }
 
-static void copy(Ui_QueryOptions* ui_queryOptions, int column)
+static void copy(Ui_QueryOptions *ui_queryOptions, int column)
 {
-    QApplication::clipboard()->setText(ui_queryOptions->treeView->currentIndex().sibling(ui_queryOptions->treeView->currentIndex().row(), column).data().toString());
+    QApplication::clipboard()->setText(
+        ui_queryOptions->treeView->currentIndex().sibling(ui_queryOptions->treeView->currentIndex().row(), column).data().toString());
 }
 
 void TMTab::copySource()
@@ -615,20 +614,20 @@ void TMTab::openFile()
 {
     QModelIndex item = ui_queryOptions->treeView->currentIndex();
     if (Settings::deleteFromTMOnMissing()) {
-        //Check if the file exists and delete it if it doesn't
+        // Check if the file exists and delete it if it doesn't
         QString filePath = item.sibling(item.row(), TMDBModel::Filepath).data(Qt::UserRole).toString();
         if (Project::instance()->isFileMissing(filePath)) {
-            //File doesn't exist
-            RemoveFileJob* job = new RemoveFileJob(filePath, ui_queryOptions->dbName->currentText());
+            // File doesn't exist
+            RemoveFileJob *job = new RemoveFileJob(filePath, ui_queryOptions->dbName->currentText());
             TM::threadPool()->start(job, REMOVEFILE);
             KMessageBox::information(this, i18nc("@info", "The file %1 does not exist, it has been removed from the translation memory.", filePath));
-            return performQuery();//We relaunch the query
+            return performQuery(); // We relaunch the query
         }
     }
     Q_EMIT fileOpenRequested(item.sibling(item.row(), TMDBModel::Filepath).data(Qt::UserRole).toString(),
-                           item.sibling(item.row(), TMDBModel::Source).data().toString(),
-                           item.sibling(item.row(), TMDBModel::Context).data().toString(),
-                           true);
+                             item.sibling(item.row(), TMDBModel::Source).data().toString(),
+                             item.sibling(item.row(), TMDBModel::Context).data().toString(),
+                             true);
 }
 
 void TMTab::setQAMode()
@@ -638,7 +637,7 @@ void TMTab::setQAMode()
 
 void TMTab::setQAMode(bool enable)
 {
-    static_cast<FastSizeHintItemDelegate*>(ui_queryOptions->treeView->itemDelegate())->reset();
+    static_cast<FastSizeHintItemDelegate *>(ui_queryOptions->treeView->itemDelegate())->reset();
 
     if (!enable) {
         m_proxyModel->setRules(QVector<Rule>());
@@ -660,10 +659,7 @@ void TMTab::setQAMode(bool enable)
     performQuery();
 }
 
-
-//END TMWindow
-
-
+// END TMWindow
 
 #if 0
 bool QueryResultDelegate::editorEvent(QEvent* event,
@@ -699,10 +695,7 @@ bool QueryResultDelegate::editorEvent(QEvent* event,
 
 #endif
 
-
-
-
-void TMTab::dragEnterEvent(QDragEnterEvent* event)
+void TMTab::dragEnterEvent(QDragEnterEvent *event)
 {
     if (dragIsAcceptable(event->mimeData()->urls()))
         event->acceptProposedAction();
@@ -712,7 +705,7 @@ void TMTab::dropEvent(QDropEvent *event)
 {
     QStringList files;
     const auto urls = event->mimeData()->urls();
-    for (const QUrl& url : urls)
+    for (const QUrl &url : urls)
         files.append(url.toLocalFile());
 
     if (scanRecursive(files, Project::instance()->projectID()))
@@ -720,7 +713,7 @@ void TMTab::dropEvent(QDropEvent *event)
 }
 
 #include "translationmemoryadaptor.h"
-//BEGIN DBus interface
+// BEGIN DBus interface
 QList<int> TMTab::ids;
 
 QString TMTab::dbusObjectPath()
@@ -760,7 +753,7 @@ void TMTab::lookup(QString source, QString target)
 bool TMTab::findGuiTextPackage(QString text, QString package)
 {
     qCWarning(LOKALIZE_LOG) << package << text;
-    QLineEdit* const source_target_query[] = {ui_queryOptions->queryTarget, ui_queryOptions->querySource};
+    QLineEdit *const source_target_query[] = {ui_queryOptions->queryTarget, ui_queryOptions->querySource};
     static const DocPosition::Part source_target[] = {DocPosition::Target, DocPosition::Source};
     QStringEncoder latin1(QStringEncoder::Latin1);
     [[maybe_unused]] const auto encoded = latin1.encode(text);
@@ -773,13 +766,14 @@ bool TMTab::findGuiTextPackage(QString text, QString package)
     source_target_query[tryNowPart == DocPosition::Source]->setText(text);
     ui_queryOptions->invertSource->setChecked(false);
     ui_queryOptions->invertTarget->setChecked(false);
-    if (!package.isEmpty()) package = QLatin1Char('*') + package + QLatin1Char('*');
+    if (!package.isEmpty())
+        package = QLatin1Char('*') + package + QLatin1Char('*');
     ui_queryOptions->filemask->setText(package);
     ui_queryOptions->queryStyle->setCurrentIndex(TMDBModel::Glob);
     performQuery();
 
     return true;
 }
-//END DBus interface
+// END DBus interface
 
 #include "moc_tmtab.cpp"
